ExPmtiles.Cache.Diagnostics (ExPmtiles v0.3.4)
View SourceDiagnostic utilities for debugging cache issues.
Summary
Functions
Cleans up dead processes from the pending table.
Gets comprehensive cache diagnostics.
Inspects the pending requests table for a given cache.
Functions
Cleans up dead processes from the pending table.
This can help recover from stuck pending entries.
Gets comprehensive cache diagnostics.
Inspects the pending requests table for a given cache.
Returns a list of pending tile requests with their waiting processes.