ExPmtiles.Cache.FileHandler (ExPmtiles v0.3.4)
View SourcePure functions for file-based cache operations.
This module handles all file system operations for the cache, including reading, writing, and clearing cache files.
Summary
Functions
Clears all cache files (both tiles and directories) for a given cache path.
Clears the directory cache directory.
Clears the tile cache directory.
Initializes cache directories for a given cache path.
Reads a tile from the cache file. Returns {:ok, tile_data} on success, :error on failure.
Generates the file path for a cached tile.
Writes tile data to a cache file. Returns :ok on success, :error on failure.
Functions
Clears all cache files (both tiles and directories) for a given cache path.
Clears the directory cache directory.
Clears the tile cache directory.
Initializes cache directories for a given cache path.
Reads a tile from the cache file. Returns {:ok, tile_data} on success, :error on failure.
Generates the file path for a cached tile.
Writes tile data to a cache file. Returns :ok on success, :error on failure.